@@ -5,7 +5,7 @@ package Test::Continuous;
 
 use 5.008;
 
-our $VERSION = '0.75';
+our $VERSION = '0.76';
 
 use File::Find;
 use Cwd;
@@ -15,20 +15,57 @@ use Test::Continuous::Formatter;
 use File::ChangeNotify;
 use Git::Repository;
 use YAML;
+use Term::Cap;
 
+my $cls;
 my @prove_args;
 my @tests;
 my @changes;
 my @not_files;
 my @classes;
 
-sub _classify_argv {
-    if (@ARGV) {
-        @not_files  = grep   { !-f $_ }     @ARGV;
-        @tests      = grep   {  -f $_ }     @ARGV;
-        @classes    = after  { $_ eq '::' } @not_files;
-        @prove_args = before { $_ eq '::' } @not_files;
+# Parse ARGV and environmental options, using AUTOPROVE_OPTS followed by
+# command-line
+# 
+# Returns a hash reference of configuration keys and values
+sub _classify_opts {
+    my @env;
+    if (defined($ENV{AUTOPROVE_OPTS})) {
+        @env = split(/\s+/os, $ENV{AUTOPROVE_OPTS});
     }
+
+    # Preserve order properly
+    my (@opts);
+    push @opts, before { $_ eq '::' } @env;
+    push @opts, @ARGV;
+    push @opts, after  { $_ eq '::' } @env;
+
+    if (@opts) {
+        my (@not_opts) = grep   { !( /^--autoprove-/i ) }   @opts;
+        @not_files     = grep   { !( -f $_ or -d $_ ) }     @not_opts;
+        @tests         = grep   {    -f $_ or -d $_   }     @not_opts;
+        @classes       = after  { $_ eq '::' } @not_files;
+        @prove_args    = before { $_ eq '::' } @not_files;
+    }
+
+    return _parse_options(@opts);
+}
+
+sub _parse_options {
+    my @opts = @_;
+    my %config;
+
+    foreach (grep { /^--autoprove-/i } @opts) {
+        if (/^--autoprove-skip-initial$/ois) {
+            $config{skip} = 1;
+        } elsif (/^--autoprove-no-skip-initial$/ois) {
+            $config{skip} = undef;
+        } else {
+            die("Unknown option: $_");
+        }
+    }
+
+    return \%config;
 }
 
 sub _tests_to_run {
@@ -100,9 +137,12 @@ sub _get_exclude_list {
 
     # Attempt to get the git directory Test::Continuous was run in
     my $path = getcwd;
-    my $git_repo_top_level = Git::Repository->run( 'rev-parse', '--show-toplevel', {
-        cwd => $path,
-    });
+    my $git_repo_top_level;
+    eval {
+        $git_repo_top_level = Git::Repository->run( 'rev-parse', '--show-toplevel', {
+            cwd => $path,
+        });
+    };
     my ( $git_ignore, $git_dir );
 
     # If the git command came up with a git repo use it's .gitignore
@@ -142,13 +182,33 @@ sub _match_against_excluded {
 
 sub _run_once {
     my $build = shift;
-    _classify_argv();
+    _classify_opts();  # We don't need the return value here
     my @tests = _tests_to_run;
     my @command_args = ( @prove_args, @tests, '::', @classes );
 
-    print "\033[2J\033[0;0H"; #cls
-    print "prove --norc " . join(" ", @command_args) . "\n";
-    system(qw(prove --norc -v -m --formatter Test::Continuous::Formatter), @command_args);
+    _cls();
+    print "prove --norc -v -m " . join(" ", @command_args) . "\n";
+
+    # This is from the prove source code
+    my $script = <<'EOS';
+        use strict;
+        use warnings;
+        use App::Prove;
+
+        my $app = App::Prove->new();
+        $app->process_args(@ARGV);
+        exit( $app->run ? 0: 1 );
+EOS
+
+    # We don't run "prove" directly because the prove in the system path
+    # may be very different than the perl that this module is running
+    # under.  So we "simulate" prove by using App::Prove (using the data
+    # in $script from above).
+    system(
+        $^X, '-e', $script,
+        qw(-- --norc -v -m --formatter Test::Continuous::Formatter),
+        @command_args
+    );
 }
 
 sub _rebuild {
@@ -182,7 +242,7 @@ sub _rebuild {
 }
 
 sub runtests {
-    _classify_argv();
+    my $config = _classify_opts();
 
     unless (@tests) {
         find sub {
@@ -191,7 +251,7 @@ sub runtests {
             push @tests, $filename;
         }, getcwd;
     }
-
+   
     print "[MSG] Will be continuously testing $_\n" for @tests;
 
     my $watcher = File::ChangeNotify->instantiate_watcher(
@@ -200,7 +260,12 @@ sub runtests {
     );
 
     @changes = ();
-    _run_once(_rebuild([]));
+
+    if ($config->{skip} ) {
+        print "[MSG] SKIP_INITIAL detected, skipping initial tests\n";
+    } else {
+        _run_once(_rebuild([]));
+    }
 
     my $running = 0;
     while ( @changes = $watcher->wait_for_events() ) {
@@ -216,6 +281,35 @@ sub runtests {
     }
 }
 
+sub _cls {
+
+    # Cache clear screen
+    if (!defined($cls)) {
+        if ( -t STDOUT ) {
+            # We are on a terminal
+            
+            my $term = Term::Cap->Tgetent({OSPEED=>9600});
+            $cls = $term->Tputs('cl');
+
+            if ($cls eq '') {
+                # It's a stupid terminal.
+                # We set this to null so it'll get a sensible default
+                # later.
+                $cls = undef;
+            }
+        }
+
+        # We're either not using a terminal or we're using a really
+        # stupid terminal.
+        if (!defined($cls)) {
+            # Not on a terminal, just skip a couple lines
+            $cls = "\n\n";
+        }
+    }
+
+    print $cls;
+}
+
 1;
 
 __END__
@@ -269,10 +363,37 @@ this distribution to do this instead.
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
-Test::Continuous requires no configuration files or environment variables.
+Test::Continuous requires no configuration files.
 
 Your C<.proverc> is NOT loaded, even though it's based on L<App::Prove>.
 
+The main C<runtests()> routine parses arguments on the command line or
+passed via the environment variable C<AUTOPROVE_OPTS>.  All autoprove
+options are prefixed with C<--autoprove-> (in both the command line and
+the environmental variable).
+
+Valid options:
+
+=over
+
+=item C<--autoprove-no-skip-initial> (Default)
+
+=item C<--autoprove-skip-initial>
+
+These options allow control over whether the initial tests are run when
+autoprove is first started. By default, C<runtests()> will run all tests
+when executed, and then wait for changes.
+
+Using C<--autoprove-skip-initial> skips the initial tests and goes
+straight to watching for changes to files.  Generally, you should run all
+tests, in case something changed while C<Test::Continuous> was not
+running.  The C<--autoprove-no-skip-initial> is provided so that you can
+override an environmental variable C<AUTOPROVE_OPTS> that includes
+C<--autoprove-skip-initial> via the command line, by passing autoprove
+the C<--autoprove-no-skip-initial> option.
+
+=back
+
 =head1 DEPENDENCIES
 
 L<App::Prove>, L<Log::Dispatch>, L<Log::Dispatch::DesktopNotification>,
